==> huaweicloudsdkrds-3.0.49-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/enable_configuration_request.py <==
# coding: utf-8

import pprint
import re

import six





class EnableConfigurationRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'config_id': 'str',
        'body': 'ApplyConfigurationRequest'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'config_id': 'config_id',
        'body': 'body'
    }

    def __init__(self, x_language=None, config_id=None, body=None):
        """EnableConfigurationRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_language = None
        self._config_id = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.config_id = config_id
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this EnableConfigurationRequest.

        语言

        :return: The x_language of this EnableConfigurationRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this EnableConfigurationRequest.

        语言

        :param x_language: The x_language of this EnableConfigurationRequest.
        :type: str
        """
        self._x_language = x_language

    @property
    def config_id(self):
        """Gets the config_id of this EnableConfigurationRequest.

        参数模板ID。

        :return: The config_id of this EnableConfigurationRequest.
        :rtype: str
        """
        return self._config_id

    @config_id.setter
    def config_id(self, config_id):
        """Sets the config_id of this EnableConfigurationRequest.

        参数模板ID。

        :param config_id: The config_id of this EnableConfigurationRequest.
        :type: str
        """
        self._config_id = config_id

    @property
    def body(self):
        """Gets the body of this EnableConfigurationRequest.


        :return: The body of this EnableConfigurationRequest.
        :rtype: ApplyConfigurationRequest
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this EnableConfigurationRequest.


        :param body: The body of this EnableConfigurationRequest.
        :type: ApplyConfigurationRequest
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableConfigurationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.0.52-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/enable_configuration_request.py <==
# coding: utf-8

import re
import six





class EnableConfigurationRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'x_language': 'str',
        'config_id': 'str',
        'body': 'ApplyConfigurationRequest'
    }

    attribute_map = {
        'x_language': 'X-Language',
        'config_id': 'config_id',
        'body': 'body'
    }

    def __init__(self, x_language=None, config_id=None, body=None):
        """EnableConfigurationRequest - a model defined in huaweicloud sdk"""
        
        

        self._x_language = None
        self._config_id = None
        self._body = None
        self.discriminator = None

        if x_language is not None:
            self.x_language = x_language
        self.config_id = config_id
        if body is not None:
            self.body = body

    @property
    def x_language(self):
        """Gets the x_language of this EnableConfigurationRequest.

        语言

        :return: The x_language of this EnableConfigurationRequest.
        :rtype: str
        """
        return self._x_language

    @x_language.setter
    def x_language(self, x_language):
        """Sets the x_language of this EnableConfigurationRequest.

        语言

        :param x_language: The x_language of this EnableConfigurationRequest.
        :type: str
        """
        self._x_language = x_language

    @property
    def config_id(self):
        """Gets the config_id of this EnableConfigurationRequest.

        参数模板ID。

        :return: The config_id of this EnableConfigurationRequest.
        :rtype: str
        """
        return self._config_id

    @config_id.setter
    def config_id(self, config_id):
        """Sets the config_id of this EnableConfigurationRequest.

        参数模板ID。

        :param config_id: The config_id of this EnableConfigurationRequest.
        :type: str
        """
        self._config_id = config_id

    @property
    def body(self):
        """Gets the body of this EnableConfigurationRequest.


        :return: The body of this EnableConfigurationRequest.
        :rtype: ApplyConfigurationRequest
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this EnableConfigurationRequest.


        :param body: The body of this EnableConfigurationRequest.
        :type: ApplyConfigurationRequest
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EnableConfigurationRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
